%Parse incoming communication data from ECG peripheral to extract ECG signal
%lastUnfinishedTail: should be provided from prior function call
%stream: Incoming data, nx2 char array
function [parsedData1,parsedData2,parsedData3,parsedData4, unfinishedTail] = parseLiveLogWHM(lastUnfinishedTail, stream)
    stream = [lastUnfinishedTail; stream];
    unfinishedTail = [];
    parsedData1 = [];
    parsedData2 = [];
    parsedData3 = [];
    parsedData4 = [];
    eventHead = 1;
%     pulseHandle = '0003';
    pulseHandle = '003D';
%     accelHandle = '0037';
    accelHandle = '0033';
%     edaHandle = '003A';
    edaHandle = '0036';
%     adcHandle = '003D';
    adcHandle = '0039';
    
    while(isempty(unfinishedTail))
        %Make sure the current packet's HEADER doesn't run off the end of the stream -_-
%         len = length(stream(:,1));
        if( (length(stream(:,1)) - eventHead) < 4) %if the length is less than the minimum packet size
            unfinishedTail = stream(eventHead:end, :);
            break;
        end
        head = stream(eventHead,:); %display head of stream: should ALWAYS be the type. For Event, should be 0x04.
        eventcode = stream(eventHead+1,:); %Display event code: should be 0xFF for received WHM data
        dataLen = hex2dec(stream(eventHead+2,:)); %Specifies the number of bytes remaining in the message
        event = [stream(eventHead+4,:) stream(eventHead+3,:)]; %Extract event.  For an ATT_HandleValueNotification, this will be 0x051B
        handle = [stream(eventHead+10,:) stream(eventHead+9,:)]; %Extract the Handle, which indicates whic notification this is
        
        
        %Ignore any packet that's not an ATT_HandleValueNotification transmission and skip to the next packet
        if(~strcmp(event, '051B')) %if we don't have a packet we want
            eventHead = eventHead+2+dataLen; %skip over this message
            continue;
        end
        
        %Now we know we're looking at WHM transmission; make sure it doesn't run off the end of the stream
        if(eventHead+2+dataLen+1 > length(stream(:,1)))
            unfinishedTail = stream(eventHead:end, :);
        else %Parse WHM transmission
            if(strcmp(handle, pulseHandle)) %if handle is for the pulse oximeter values
                %save in bytes cause some data is only a byte long
                parsedData4 = [parsedData4; stream(eventHead+12:1:eventHead+2+dataLen,:)]; %save just the message data
            else %else it's another message that deals with multiples of 2 bytes
                %Re-assemble transmitted data into 2-byte numbers
                parsedPacketData = [stream(eventHead+12:2:eventHead+2+dataLen,:), stream(eventHead+11:2:eventHead+2+dataLen-1,:)];
%               fwrite(fid_2,hex2dec(parsedPacketData),'double');
                if(strcmp(handle, accelHandle)) %if the handle is for the accel value
                    parsedData1 = [parsedData1; parsedPacketData];
                end
                if(strcmp(handle, edaHandle)) %if the handle is for the EDA value
                    parsedData2 = [parsedData2; parsedPacketData];
                end
                if(strcmp(handle, adcHandle)) %if the handle is for the adc values
                    parsedData3 = [parsedData3; parsedPacketData];
                end
%                 if(strcmp(handle, '0003')) %if handle is for the pulse oximeter values
%                     parsedData4 = [parsedData4; parsedPacketData];
%                 end
            end
        end
        eventHead = eventHead+2+dataLen+1; %get to the next message
    end
end

